@@ -17,12 +17,13 @@ require_once('include/CIConfig.php');
  * @detail
  *  No details yet.
  *
- * @author Peter Bubestinger-Steindl
+ * @author Peter Bubestinger-Steindl (pb@av-rd.com)
  * @copyright
- *  Copyright 2016, Peter Bubestinger-Steindl
+ *  Copyright 2018 AV-RD e.U.
  *  (License: <a href="http://www.gnu.org/licenses/gpl.html">GNU General Public License (v3)</a>)
  *
  * @see
+ *  - <a href="http://www.av-rd.com/products/cinbox/">CInbox product website</a>
  *  - <a href="http://www.av-rd.com/">AV-RD Company Website</a>
  *  - <a href="https://fsfe.org/about/basics/freesoftware.en.html">FSFE: What is Free Software?</a>
  */
@@ -37,6 +38,7 @@ define('OPT_CONFIG_FILE', 'configfile');
 define('OPT_LANGUAGE', 'language');
 define('OPT_LOGFILE', 'logfile');
 define('OPT_FOREVER', 'forever');
+define('OPT_LOGSTYLE', 'logstyle');
 
 // Exit codes:
 define('EXIT_OK', 0);
@@ -73,6 +75,7 @@ function parseArgs()
     $shortOpts = "i:p:c:n:w:hv";
     $longOpts = array(
             'debug',                    // logLevel = DEBUG
+            'logstyle:',                // Set output format of Item log
             'lang:',                    // Set language. Syntax is same as in config file: de_DE, en_GB, etc...
             'log:',                     // Set logfile for inbox (items will have their own)
             'forever',                  // Continue loop until cancelled by user
@@ -118,6 +121,19 @@ function parseArgs()
         $l->logDebug(print_r($options, true));
     }
 
+    if (isset($options['logstyle']))
+    {
+        $logstyle = $options['logstyle'];
+        try { Logger::validateOutputFormat($logstyle); }
+        catch (Exception $e)
+        {
+            $l->logError($e->getMessage());
+            return false;
+        }
+
+        $config->set(OPT_LOGSTYLE, $logstyle);
+    }
+
     if (isset($options['lang']))
     {
         $config->set(OPT_LANGUAGE, $options['lang']);
@@ -165,7 +181,7 @@ function showVersion()
 function showHelp()
 {
     showVersion();
-    printf("
+    printf(_("
 Usage: %s [OPTION]
 
 Mandatory arguments:
@@ -177,6 +193,8 @@ Optional arguments:
   -p                         Processing folder (contains logs, etc)
   -v                         Verbose mode (logLevel = INFO)
   --debug                    Debug mode (logLevel = DEBUG)
+  --logstyle STYLE           Set output format of Item log
+                             STYLE can be: 'classic' or 'cv'
   --lang                     Set language. Syntax is same as in config file: de_DE, en_GB, etc.
   --log                      Set logfile for inbox (items will have their own)
   --forever                  Continue looping/waiting for items until interrupted by user
@@ -189,7 +207,7 @@ EXIT VALUES
   %d      Runtime error
   %d      Errors occurred while processing an item
 
-",
+"),
         basename(__FILE__),
         EXIT_OK,
         EXIT_ERROR_ARGS,
@@ -269,6 +287,7 @@ function initInbox()
 
     $cinbox->setSourceFolder($config->get(OPT_SOURCE_FOLDER));
     $cinbox->setConfigFile($config->get(OPT_CONFIG_FILE));
+    $cinbox->setItemLogstyle($config->get(OPT_LOGSTYLE));
     $result = $cinbox->initInbox();
 
     return $result;
@@ -283,10 +302,8 @@ function initInbox()
 // Initialize output/logging:
 $logger = new Logger();
 $l = $logger;                           // Alias as shortcut.
-$config = new CIConfig($logger);
-// Use new FileCV logging style.
-$logger->setUsingFileCV(true);
 
+$config = new CIConfig($logger);
 $config->set(OPT_FOREVER, false);       // Don't continue forever by default.
 
 // Parse commandline arguments:
