@@ -147,6 +147,14 @@ class CIConfig
         return true;
     }
 
+    /**
+     * Returns the current placeholders array as-is.
+     */
+    public function getPlaceholders()
+    {
+        return $this->placeholders;
+    }
+
 
     /**
      * Short for "setSetting".
