@@ -318,6 +318,9 @@ class CIItem extends CIFolder
      * something like "buckets" which divides the amount of ItemIDs over several subfolders,
      * following a custom syntax (which would be in the external script).
      */
+    // TODO: Don't hardcode the arguments provided to the bucket script, but
+    //       rather let the user decide in the configfile which values to pass.
+    //       (just like pre/postproc scripts)
     public function callBucketScript($script, &$bucket)
     {
         $l = $this->logger;
@@ -335,16 +338,25 @@ class CIItem extends CIFolder
                         $script));
         }
 
-        $command = sprintf('%s %s', $script, $this->itemId);
+        // Provide ItemID and Item's path to bucket script:
+        $command = sprintf("%s %s '%s'",
+                $script,
+                $this->itemId,
+                $this->getPathname());
+
+        $l->logInfo(sprintf(
+                    _("Calling bucket script '%s' with item ID '%s'..."),
+                    $script,
+                    $this->itemId,
+                    $this->getPathname()));
 
-        $l->logInfo(sprintf(_("Calling bucket script '%s' with item ID '%s'..."), $script, $this->itemId));
         $exec = new CIExec();
         $exitCode = $exec->execute2($command);
 
         if ($exitCode != CIExec::EC_OK) return $exitCode;
 
         $result = $exec->getLastOutput();
-        $bucket = $result[0];
+        $bucket = $result[0]; // Only return *1st* line of output from script!
         $l->logMsg(sprintf(_("Bucket script returned '%s'."), $bucket));
         return true;
     }
@@ -434,12 +446,18 @@ class CIItem extends CIFolder
 
         //----------------.
         $folder = new CIFolder($l, $folderName, $baseFolder);
+        // FIXME: Why is $folderName provided as function parameter when it's
+        //        not read before it's overwritten/initialized here?
         $folderName = $folder->getPathname();
         $folder->setParentItem($this);
         $folder->setParentFolder($parent);
         $folder->setTempFolder($this->getTempFolder());
         $l->logDebug(sprintf(_("Initializing Item subfolder: '%s' (=%s) / base: '%s'"), $folderName, $folder->getSubDir(), $baseFolder));
 
+        // Set as many placeholder values that we can already provide at this point:
+        $itemConfig->addPlaceholder(__DIR_BASE__, $baseFolder);
+        $itemConfig->addPlaceholder(__DIR_SOURCE__, $folderName);
+
         // Copy configuration contents (!), but *not* the config-object from item to folder:
         // IMPORTANT: We use the *resolved* config from Item, so that common placeholders are not resolved twice.
         $folderConfig = $folder->getConfig();
