@@ -525,6 +525,66 @@ class Helper
         return $stats;
     }
 
+
+    /**
+     * Returns the basename of a file (without path).
+     *
+     * @param $filename     [string]    Regular filename string, with or without path.
+     * @param $suffix       [bool]      Return filename without file suffix if 'false'.
+     *
+     * @retval boolean
+     *  Returns 'true' if successful,
+     *  'False' if an error occurred.
+     */
+    public static function getBasename($filename, $suffix=true)
+    {
+        $pathinfo = pathinfo($filename);
+
+        return ( $suffix ? $pathinfo['basename'] : $pathinfo['filename'] );
+    }
+
+
+    /**
+     * Resolves a given path relative to a given base, and returns the absolute
+     * path (+filename if given).
+     *
+     * It's merely a call to realpath(), but works if the file doesn't exist
+     * (yet).
+     * BUT: The path must already exist!
+     *
+     * @param $filename     [string]    Path or path+filename.
+     * @param $base         [string]    Folder to consider as base for relative $filename.
+     */
+    public static function getAbsoluteName($filename, $base=null)
+    {
+        if (!empty($base))
+        {
+            // We don't check if $filename is absolute or relative, and assume
+            // that if $base is set, it's relative.
+            $filename = $base . DIRECTORY_SEPARATOR . $filename;
+        }
+
+        $pathinfo = pathinfo($filename);
+
+        // If it exists, we're happy to use realpath as-is:
+        if (file_exists($filename)) return realpath($filename);
+
+        $basename = $pathinfo['basename'];
+        $dir = $pathinfo['dirname'];
+
+        $realDir = realpath($dir);
+        if ($realDir === false) throw new RuntimeException(
+                sprintf(_("Unable to resolve absolute path. Folder does not exist: '%s'"),
+                    $dir
+                    ));
+
+        $absolute = $realDir . DIRECTORY_SEPARATOR . $basename;
+
+        return $absolute;
+    }
+
+
+
 }
 
 ?>
