@@ -1,5 +1,10 @@
 <?php
 
+/*
+ * TODO:
+ * Have task-specific placeholders be added by a new task rather than here.
+ */
+
 // Stringmask placeholders:
 
 define('__ITEM_ID__', '[@ITEM_ID@]');           // Item ID = Object identifier = archive signature
@@ -18,10 +23,17 @@ define('__SECOND__', '[@MINUTE@]');
 define('__DATETIME__', '[@DATETIME@]');
 
 
+define('__DIR_IN__', '[@DIR_IN@]');                 // Path of input file
 define('__FILE_IN__', '[@FILE_IN@]');               // A filename (in/source)
+define('__FILE_IN_NOEXT__', '[@FILE_IN_NOEXT@]');   // FILE_IN without its suffix/extension
+
+define('__DIR_OUT__', '[@DIR_OUT@]');               // Path of output file
 define('__FILE_OUT__', '[@FILE_OUT@]');             // A filename (out/target)
+define('__FILE_OUT_NOEXT__', '[@FILE_OUT_NOEXT@]'); // FILE_OUT without its suffix/extension
+
 define('__LOGFILE__', '[@LOGFILE@]');               // Name of a logfile
 
+
 define('__OPTIONS__', '[@OPTIONS@]');               // Options/arguments (provided to e.g. external commands)
 
 define('__HASHTYPE__', '[@HASHTYPE@]');             // A hashcode type (md5, sha1, crc, etc)
