@@ -39,7 +39,7 @@ require_once('include/Helper.php');
  *  - <a href="https://fsfe.org/about/basics/freesoftware.en.html">FSFE: What is Free Software?</a>
  *  - <a href="http://www.gnu.org/licenses/gpl.html">The GNU General Public License</a>
  */
-class TaskCopyRsync extends TaskCopy
+abstract class TaskCopyRsync extends TaskCopy
 {
     /* ========================================
      * CONSTANTS
@@ -48,8 +48,7 @@ class TaskCopyRsync extends TaskCopy
     // Task name/label:
     const TASK_LABEL = 'Copy files using RSync (abstract)';
 
-    // This command is called for performing the actual copy.
-    const BIN_RSYNC = 'rsync';
+    const BIN_RSYNC = 'rsync';                          ///< This command is called for performing the actual copy.
     const CMD_COPY_MASK = 'rsync --progress --times --copy-links --inplace --log-file="[@LOGFILE@]" "[@FILE_IN@]" "[@FILE_OUT@]"';
     const CMD_COPY_MASK_DEBUG = 'rsync --dry-run -v --progress --times --copy-links --inplace --log-file="[@LOGFILE@]" "[@FILE_IN@]" "[@FILE_OUT@]"';
 
