@@ -61,7 +61,7 @@ abstract class TaskExec extends CITask
      * All programs/scripts executed by this task must implement these
      * exit codes. Otherwise, a non-0 exitcode might lead to undesired,
      * possibly catastrophic results.
-     * If you need to execute an arbitrary program, please use a 
+     * If you need to execute an arbitrary program, please use a
      * wrapper-script of some kind to return these exit codes as desired.
      */
     //@{
@@ -81,6 +81,14 @@ abstract class TaskExec extends CITask
 
     protected $exec;
 
+    /**
+     * $logFile: Contains filename for output of external command execution.
+     * But should only be used if exactly 1 command is called once per class
+     * instantiation. Otherwise, please resolve logfile name using getCmdLogfile()
+     * right before executing the external application.
+     */
+    protected $logFile;
+
 
 
     /* ========================================
@@ -203,6 +211,114 @@ abstract class TaskExec extends CITask
     }
 
 
+    /**
+     * Get filename of logfile to use for external command execution.
+     * Filename is "$prefix + DATEIME" (TIME precision: seconds).
+     * If $prefix is empty, the task name will be used.
+     *
+     * NOTE: Assumes $this->tempFolder to be set and initialized.
+     *
+     * @param $prefix   [string]    String to prefix logfile name with.
+     *
+     * @See: self::checkTempFolder()
+     */
+    protected function getCmdLogfile($prefix=null)
+    {
+        // Check if we have a proper temp folder:
+        if (!$this->checkTempFolder()) return false;
+
+        if (empty($prefix)) $prefix = $this->name;
+
+        $logFile = Helper::resolveString(
+                $this->tempFolder . DIRECTORY_SEPARATOR . $prefix . __DATETIME__ . '.log',
+                array(__DATETIME__ => date('Ymd_His'))
+                );
+
+        return $logFile;
+    }
+
+
+    /**
+     * Removes/deletes the logfile used for external command execution.
+     * @See self::getCmdLogfile()
+     */
+    protected function removeCmdLogfile($logFile=null)
+    {
+        $l = $this->logger;
+
+        // If no filename is given, use the task's property:
+        if (empty($logFile)) $logFile = $this->logFile;
+
+        if (empty($logFile))
+        {
+            //This shouldn't happen, but well...
+            $l->logError(sprintf(
+                        _("Logfile for task '%s' cannot be deleted, since no filename has been set. This is odd, but not critical."),
+                        $this->name
+                        ));
+            $this->setStatusPBC();
+            return false;
+        }
+
+        if (!file_exists($logFile))
+        {
+            // Logfile isn't there, so remove can report "success" ;)
+            $l->logDebug(sprintf(_("Logfile '%s' removed, since it didn't exist in the first place ;)"), $logFile));
+            return true;
+        }
+
+        if (!is_writable($logFile))
+        {
+            $l->logError(sprintf(_("Logfile '%s' cannot be deleted, because it is not writable. Check access rights?"), $logFile));
+            // Mark this "problem but continue", since it is non-critical to this or following tasks:
+            $this->setStatusPBC();
+            return false;
+        }
+
+        if (!unlink($logFile))
+        {
+            $l->logError(sprintf(_("Logfile '%s' could not be deleted. Unknown reason."), $logFile));
+            // Mark this "problem but continue", since it is non-critical to this or following tasks:
+            $this->setStatusPBC();
+            return false;
+        }
+
+        $l->logDebug(sprintf(_("Logfile '%s' was deleted."), $logFile));
+        return true;
+    }
+
+
+    /**
+     * Used to write a message to the command execution logfile.
+     * Appends if file already exists, otherwise creates it before.
+     */
+    protected function writeToCmdLogfile($msg, $logFile=null)
+    {
+        $l = $this->logger;
+
+        // Nothing to do. Nothing done. Okay.
+        if (empty($msg)) return true;
+
+        // If no filename is given, use the task's property:
+        if (empty($logFile)) $logFile = $this->logFile;
+
+        if (!file_exists($logFile)) touch($logFile);
+
+        $result = file_put_contents($logFile, $msg, FILE_APPEND);
+        if ($result > 0)
+        {
+            $l->logDebug(sprintf(_("Wrote message to logfile '%s' (%d bytes):\n%s"), $logFile, $result, $msg));
+        }
+        else
+        {
+            $l->logError(sprintf(_("Error writing message '%s' to logfile '%s'."), $msg, $logFile));
+            return false;
+        }
+
+        return $result;
+    }
+
+
 
 }
 
