@@ -35,14 +35,16 @@ require_once('include/CIFolder.php');
  *  - <a href="https://fsfe.org/about/basics/freesoftware.en.html">FSFE: What is Free Software?</a>
  *  - <a href="http://www.gnu.org/licenses/gpl.html">The GNU General Public License</a>
  */
+// TODO: Change the class name to match your case:
 class TaskSkeleton extends CITask
 {
     /* ========================================
      * CONSTANTS
      * ======================================= */
 
-    // Task name/label:
-    const TASK_LABEL = 'Task Skeleton';                    ///< TODO: Change the taskname
+    // TODO: Change the taskname here:
+    //       (this is not a description, just a label!)
+    const TASK_LABEL = 'Task Skeleton';                     ///< Human readable task name/label.
 
     /**
      * @name Task Settings
@@ -50,6 +52,12 @@ class TaskSkeleton extends CITask
      */
     //@{
     // TODO: Names of config settings used by a task must be defined here.
+    //       Config names shall start with "CONF_" (see examples below).
+    //       Each config entry must be documented inline with "///<".
+    //
+    //       Examples:
+    //          const CONF_HASH_TYPE = 'HASH_TYPE';         ///< Define which hash type
+    //          const CONF_MUST_EXIST = 'MUST_EXIST';       ///< Stuff that must exist
     //@}
 
 
@@ -140,8 +148,9 @@ class TaskSkeleton extends CITask
     {
         if (!parent::finalize()) return false;
 
-        // TODO: Optional. Initialize things here before running the task.
-        // TODO: Add here what the task is supposed to do.
+        // TODO: Optional. Do things here that need to be done *after*
+        //       the actual task has finished.
+        //       For example clean-up things or so.
 
         // Must return true on success:
         return true;
